# Roadmap

## P0
P0 feature is the current task we're focusing on.
There would be one and only one P0 task

- [ ] Common C & C++ structs

## P1
P1 features are side tasks.

One of them will be moved to P0 once after P0 task is completed.

- [x] Python 3.x bindings
- [ ] Cross-platform support core
- [ ] Addons framework
- [ ] [Example] Network sniffer


## P2
P2 features are scheduled features.

Some of them will be moved to P1 when timing is right.

- Android platform support
- IOS platform support

## P3
P3 features are requested features

Some of them will be moved to P2 upon priority change requests.
- Linux Platform support
- OSX Platform support

## Completed

- Windows platform support
- Python(64bit) 3.10 api bindings
- Python(32bit) 3.9 api bindings
- Python Limited API bindings
